use conf::CONFIG;

pub mod backends;
pub mod conf;
pub mod data;
pub mod schema;
pub mod models;

fn prepare_logger() {
    // Fern
    fern::Dispatch::new()
        .format(|out, message, record| {
            out.finish(format_args!(
                "{}[{}][{}] {}",
                chrono::Local::now().format("[%Y-%m-%d][%H:%M:%S]"),
                record.target(),
                record.level(),
                message
            ))
        })
        .level(log::LevelFilter::Debug)
        .chain(std::io::stdout())
        .apply()
        .expect("Failed to initialize logger");
}

fn main() {
    // Prepare logger
    prepare_logger();

    // Load configuration
    let config = CONFIG.clone();

    // Print configuration
    println!("Configuration: {:#?}", config);
}